@@ -235,13 +235,11 @@ enum [[deprecated]] : int {
     SBK_QTLOCATION_QLIST_QGEOROUTEREQUEST_FEATURETYPE_IDX    = 20, // QList<QGeoRouteRequest::FeatureType>
     SBK_QTLOCATION_QLIST_QGEOROUTE_IDX                       = 22, // QList<QGeoRoute>
     SBK_QTLOCATION_QLIST_QGEOROUTESEGMENT_IDX                = 24, // QList<QGeoRouteSegment>
-    SBK_QTLOCATION_QLIST_QOBJECTPTR_IDX                      = 26, // QList<QObject*>
-    SBK_QTLOCATION_QLIST_QBYTEARRAY_IDX                      = 28, // QList<QByteArray>
-    SBK_QTLOCATION_QLIST_QLOCALE_IDX                         = 30, // QList<QLocale>
-    SBK_QTLOCATION_QLIST_QGEOLOCATION_IDX                    = 32, // QList<QGeoLocation>
-    SBK_QTLOCATION_QLIST_QVARIANT_IDX                        = 34, // QList<QVariant>
-    SBK_QTLOCATION_QLIST_QSTRING_IDX                         = 36, // QList<QString>
-    SBK_QTLOCATION_CONVERTERS_IDX_COUNT                      = 38,
+    SBK_QTLOCATION_QLIST_QLOCALE_IDX                         = 26, // QList<QLocale>
+    SBK_QTLOCATION_QLIST_QGEOLOCATION_IDX                    = 28, // QList<QGeoLocation>
+    SBK_QTLOCATION_QLIST_QVARIANT_IDX                        = 30, // QList<QVariant>
+    SBK_QTLOCATION_QLIST_QSTRING_IDX                         = 32, // QList<QString>
+    SBK_QTLOCATION_CONVERTERS_IDX_COUNT                      = 34,
 };
 
 // Converter indices
@@ -259,13 +257,11 @@ enum : int {
     SBK_QtLocation_QList_QGeoRouteRequest_FeatureType_IDX    = 10, // QList<QGeoRouteRequest::FeatureType>
     SBK_QtLocation_QList_QGeoRoute_IDX                       = 11, // QList<QGeoRoute>
     SBK_QtLocation_QList_QGeoRouteSegment_IDX                = 12, // QList<QGeoRouteSegment>
-    SBK_QtLocation_QList_QObjectPTR_IDX                      = 13, // QList<QObject*>
-    SBK_QtLocation_QList_QByteArray_IDX                      = 14, // QList<QByteArray>
-    SBK_QtLocation_QList_QLocale_IDX                         = 15, // QList<QLocale>
-    SBK_QtLocation_QList_QGeoLocation_IDX                    = 16, // QList<QGeoLocation>
-    SBK_QtLocation_QList_QVariant_IDX                        = 17, // QList<QVariant>
-    SBK_QtLocation_QList_QString_IDX                         = 18, // QList<QString>
-    SBK_QtLocation_CONVERTERS_IDX_COUNT                      = 19,
+    SBK_QtLocation_QList_QLocale_IDX                         = 13, // QList<QLocale>
+    SBK_QtLocation_QList_QGeoLocation_IDX                    = 14, // QList<QGeoLocation>
+    SBK_QtLocation_QList_QVariant_IDX                        = 15, // QList<QVariant>
+    SBK_QtLocation_QList_QString_IDX                         = 16, // QList<QString>
+    SBK_QtLocation_CONVERTERS_IDX_COUNT                      = 17,
 };
 // Macros for type check
 
