@@ -100,7 +100,7 @@ static PyObject *settingsTypeCoercion(const QVariant &out, PyTypeObject *typeObj
         // Convert any string, etc, to a list of 1 element
         if (auto *primitiveValue = convertToPrimitiveType(out, out.typeId())) {
             PyObject *list = PyList_New(1);
-            PyList_SET_ITEM(list, 0, primitiveValue);
+            PyList_SetItem(list, 0, primitiveValue);
             return list;
         }
 
@@ -113,7 +113,7 @@ static PyObject *settingsTypeCoercion(const QVariant &out, PyTypeObject *typeObj
         PyObject *list = PyList_New(valuesSize);
         for (Py_ssize_t i = 0; i < valuesSize; ++i) {
             PyObject *item = PyUnicode_FromString(valuesList.at(i).constData());
-            PyList_SET_ITEM(list, i, item);
+            PyList_SetItem(list, i, item);
         }
         return list;
     }
@@ -259,9 +259,9 @@ static QVariant QVariant_convertToVariantList(PyObject *list)
 
     QList<QVariant> lst;
     Shiboken::AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
-    const Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
+    const Py_ssize_t size = PySequence_Size(fast.object());
     for (Py_ssize_t i = 0; i < size; ++i) {
-        PyObject *pyItem = PySequence_Fast_GET_ITEM(fast.object(), i);
+        Shiboken::AutoDecRef pyItem(PySequence_GetItem(fast.object(), i));
         QVariant item = %CONVERTTOCPP[QVariant](pyItem);
         lst.append(item);
     }
@@ -322,7 +322,7 @@ QByteArray uncompressed = %FUNCTION_NAME(ptr, %2);
 QList<QByteArray> version = QByteArray(qVersion()).split('.');
 PyObject *pyQtVersion = PyTuple_New(3);
 for (int i = 0; i < 3; ++i)
-    PyTuple_SET_ITEM(pyQtVersion, i, PyLong_FromLong(version[i].toInt()));
+    PyTuple_SetItem(pyQtVersion, i, PyLong_FromLong(version[i].toInt()));
 PyModule_AddObject(module, "__version_info__", pyQtVersion);
 PyModule_AddStringConstant(module, "__version__", qVersion());
 // @snippet qt-version
@@ -434,11 +434,11 @@ static void msgHandlerCallback(QtMsgType type, const QMessageLogContext &ctx, co
 {
     Shiboken::GilState state;
     Shiboken::AutoDecRef arglist(PyTuple_New(3));
-    PyTuple_SET_ITEM(arglist, 0, %CONVERTTOPYTHON[QtMsgType](type));
-    PyTuple_SET_ITEM(arglist, 1, %CONVERTTOPYTHON[QMessageLogContext &](ctx));
+    PyTuple_SetItem(arglist, 0, %CONVERTTOPYTHON[QtMsgType](type));
+    PyTuple_SetItem(arglist, 1, %CONVERTTOPYTHON[QMessageLogContext &](ctx));
     QByteArray array = msg.toUtf8();  // Python handler requires UTF-8
     const char *data = array.constData();
-    PyTuple_SET_ITEM(arglist, 2, %CONVERTTOPYTHON[const char *](data));
+    PyTuple_SetItem(arglist, 2, %CONVERTTOPYTHON[const char *](data));
     Shiboken::AutoDecRef ret(PyObject_CallObject(qtmsghandler, arglist));
 }
 // @snippet qt-messagehandler
@@ -474,8 +474,8 @@ namespace PySide {
 QPointF p;
 %RETURN_TYPE retval = %CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, &p);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[QPointF](p));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[QPointF](p));
 // @snippet qlinef-intersect
 
 // @snippet qresource-data
@@ -498,23 +498,26 @@ if (!PyDateTimeAPI)
 int year, month, day;
 %CPPSELF.%FUNCTION_NAME(&year, &month, &day);
 %PYARG_0 = PyTuple_New(3);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[int](year));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[int](month));
-PyTuple_SET_ITEM(%PYARG_0, 2, %CONVERTTOPYTHON[int](day));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[int](year));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[int](month));
+PyTuple_SetItem(%PYARG_0, 2, %CONVERTTOPYTHON[int](day));
 // @snippet qdate-getdate
 
 // @snippet qdate-weeknumber
 int yearNumber;
 int week = %CPPSELF.%FUNCTION_NAME(&yearNumber);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[int](week));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[int](yearNumber));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[int](week));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[int](yearNumber));
 // @snippet qdate-weeknumber
 
 // @snippet qdatetime-1
 QDate date(%1, %2, %3);
 QTime time(%4, %5, %6, %7);
-%0 = new %TYPE(date, time, Qt::TimeSpec(%8));
+%0 = new %TYPE(date, time,
+               Qt::TimeSpec(%8) == Qt::UTC
+               ? QTimeZone(QTimeZone::UTC) : QTimeZone(QTimeZone::LocalTime));
+Shiboken::Warnings::warnDeprecated("QDateTime", "QDateTime(..., Qt::TimeSpec spec)");
 // @snippet qdatetime-1
 
 // @snippet qdatetime-2
@@ -526,7 +529,9 @@ QTime time(%4, %5, %6);
 // @snippet qdatetime-3
 QDate date(%1, %2, %3);
 QTime time(%4, %5, %6, %7);
-%0 = new %TYPE(date, time, %8);
+%0 = new %TYPE(date, time,
+               %8 == Qt::UTC ? QTimeZone(QTimeZone::UTC) : QTimeZone(QTimeZone::LocalTime));
+Shiboken::Warnings::warnDeprecated("QDateTime", "QDateTime(..., Qt::TimeSpec spec)");
 // @snippet qdatetime-3
 
 // @snippet qdatetime-topython
@@ -831,7 +836,7 @@ static PyBufferProcs SbkQByteArrayBufferProc = {
 // @snippet qbytearray-bufferprotocol
 
 // @snippet qbytearray-operatorplus-1
-QByteArray ba = QByteArray(PyBytes_AS_STRING(%PYARG_1), PyBytes_GET_SIZE(%PYARG_1)) + *%CPPSELF;
+QByteArray ba = QByteArray(PyBytes_AsString(%PYARG_1), PyBytes_Size(%PYARG_1)) + *%CPPSELF;
 %PYARG_0 = %CONVERTTOPYTHON[QByteArray](ba);
 // @snippet qbytearray-operatorplus-1
 
@@ -852,7 +857,7 @@ QByteArray ba = *%CPPSELF + QByteArray(PyByteArray_AsString(%PYARG_1), PyByteArr
 // @snippet qbytearray-operatorequalequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF == ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -861,7 +866,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatornotequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF != ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -870,7 +875,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorgreater
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF > ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -879,7 +884,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorgreaterequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF >= ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -888,7 +893,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorlower
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF < ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -897,7 +902,7 @@ if (PyUnicode_CheckExact(%PYARG_1)) {
 // @snippet qbytearray-operatorlowerequal
 if (PyUnicode_CheckExact(%PYARG_1)) {
     Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(%PYARG_1));
-    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
+    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_Size(data.object()));
     bool cppResult = %CPPSELF <= ba;
     %PYARG_0 = %CONVERTTOPYTHON[bool](cppResult);
 }
@@ -918,7 +923,7 @@ Py_DECREF(aux);
 // @snippet qbytearray-2
 
 // @snippet qbytearray-3
-%0 = new QByteArray(PyBytes_AS_STRING(%PYARG_1), PyBytes_GET_SIZE(%PYARG_1));
+%0 = new QByteArray(PyBytes_AsString(%PYARG_1), PyBytes_Size(%PYARG_1));
 // @snippet qbytearray-3
 
 // @snippet qbytearray-py3
@@ -1136,8 +1141,8 @@ if (msec == 0) {
 qint64 pid;
 %RETURN_TYPE retval = %TYPE::%FUNCTION_NAME(%1, %2, %3, &pid);
 %PYARG_0 = PyTuple_New(2);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[qint64](pid));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](retval));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[qint64](pid));
 // @snippet qprocess-startdetached
 
 // @snippet qcoreapplication-init
@@ -1145,7 +1150,7 @@ static void QCoreApplicationConstructor(PyObject *self, PyObject *pyargv, QCoreA
 {
     static int argc;
     static char **argv;
-    PyObject *stringlist = PyTuple_GET_ITEM(pyargv, 0);
+    PyObject *stringlist = PyTuple_GetItem(pyargv, 0);
     if (Shiboken::listToArgcArgv(stringlist, &argc, &argv, "PySideApp")) {
         *cptr = new QCoreApplicationWrapper(argc, argv);
         Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(self));
@@ -1233,7 +1238,7 @@ PySideEasingCurveFunctor::init();
 // @snippet qeasingcurve
 
 // @snippet qeasingcurve-setcustomtype
-QEasingCurve::EasingFunction func = PySideEasingCurveFunctor::createCustomFuntion(%PYSELF, %PYARG_1);
+QEasingCurve::EasingFunction func = PySideEasingCurveFunctor::createCustomFunction(%PYSELF, %PYARG_1);
 if (func)
     %CPPSELF.%FUNCTION_NAME(func);
 // @snippet qeasingcurve-setcustomtype
@@ -1268,26 +1273,24 @@ QT_END_NAMESPACE
 // @snippet qt-registerresourcedata
 
 // @snippet qt-qregisterresourcedata
-%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_2)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_3)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_4)));
+%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_2)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_3)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_4)));
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qt-qregisterresourcedata
 
 // @snippet qt-qunregisterresourcedata
-%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_2)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_3)),
-                                     reinterpret_cast<uchar *>(PyBytes_AS_STRING(%PYARG_4)));
+%RETURN_TYPE %0 = %FUNCTION_NAME(%1, reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_2)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_3)),
+                                     reinterpret_cast<uchar *>(PyBytes_AsString(%PYARG_4)));
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
 // @snippet qt-qunregisterresourcedata
 
-// @snippet use-stream-for-format-security
-// Uses the stream version for security reasons
-// see gcc man page at -Wformat-security
+// @snippet qdebug-format-string
 Py_BEGIN_ALLOW_THREADS
-%FUNCTION_NAME() << %1;
+%FUNCTION_NAME("%s", %1); // Uses placeholder for security reasons
 Py_END_ALLOW_THREADS
-// @snippet use-stream-for-format-security
+// @snippet qdebug-format-string
 
 // @snippet qresource-registerResource
  auto ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(%PYARG_1));
@@ -1321,8 +1324,8 @@ QString &res = *%0;
 // @snippet return-readData
 %RETURN_TYPE %0 = 0;
 if (PyBytes_Check(%PYARG_0)) {
-    %0 = PyBytes_GET_SIZE(%PYARG_0.object());
-    memcpy(%1, PyBytes_AS_STRING(%PYARG_0.object()), %0);
+    %0 = PyBytes_Size(%PYARG_0.object());
+    memcpy(%1, PyBytes_AsString(%PYARG_0.object()), %0);
 } else if (Shiboken::String::check(%PYARG_0.object())) {
     %0 = Shiboken::String::len(%PYARG_0.object());
     memcpy(%1, Shiboken::String::toCString(%PYARG_0.object()), %0);
@@ -1354,7 +1357,7 @@ Py_END_ALLOW_THREADS
     if (!atexit.isNull() && !regFunc.isNull()){
         PyObject *shutDownFunc = PyObject_GetAttrString(module, "__moduleShutdown");
         Shiboken::AutoDecRef args(PyTuple_New(1));
-        PyTuple_SET_ITEM(args, 0, shutDownFunc);
+        PyTuple_SetItem(args, 0, shutDownFunc);
         Shiboken::AutoDecRef retval(PyObject_Call(regFunc, args, nullptr));
         Q_ASSERT(!retval.isNull());
     }
@@ -1583,7 +1586,7 @@ int usec = PyDateTime_TIME_GET_MICROSECOND(%in);
 // @snippet conversion-qtime-pytime
 
 // @snippet conversion-qbytearray-pybytes
-%out = %OUTTYPE(PyBytes_AS_STRING(%in), PyBytes_GET_SIZE(%in));
+%out = %OUTTYPE(PyBytes_AsString(%in), PyBytes_Size(%in));
 // @snippet conversion-qbytearray-pybytes
 
 // @snippet conversion-qbytearray-pybytearray
@@ -1606,6 +1609,14 @@ return PyBool_FromLong((bool)%in);
 return PyBytes_FromStringAndSize(%in.constData(), %in.size());
 // @snippet return-pybytes
 
+// @snippet chrono-to-pylong
+return PyLong_FromLong(%in.count());
+// @snippet chrono-to-pylong
+
+// @snippet pylong-to-chrono
+%out = %OUTTYPE(PyLong_AsLongLong(%in));
+// @snippet pylong-to-chrono
+
 // @snippet return-pylong
 return PyLong_FromLong(%in);
 // @snippet return-pylong
@@ -1806,13 +1817,6 @@ if (dataChar == nullptr) {
 }
 // @snippet qdatastream-read-bytes
 
-// @snippet qloggingcategory_to_cpp
-// PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
-    QLoggingCategory *category{nullptr};
-    Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type,
-    pyArgs[0], &(category));
-// @snippet qloggingcategory_to_cpp
-
 // Q_ARG()-equivalent
 // @snippet q_arg
 const QArgData qArgData = qArgDataFromPyType(%1);
@@ -2079,7 +2083,7 @@ auto callback = [callable, arg_qpermission](const QPermission &permission) -> vo
     Shiboken::GilState state;
     if (arg_qpermission) {
         Shiboken::AutoDecRef arglist(PyTuple_New(1));
-        PyTuple_SET_ITEM(arglist.object(), 0, %CONVERTTOPYTHON[QPermission](permission));
+        PyTuple_SetItem(arglist.object(), 0, %CONVERTTOPYTHON[QPermission](permission));
         Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
     } else {
         Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
@@ -2098,9 +2102,9 @@ qint64 pid{};
 QString hostname, appname;
 %CPPSELF.%FUNCTION_NAME(&pid, &hostname, &appname);
 %PYARG_0 = PyTuple_New(3);
-PyTuple_SET_ITEM(%PYARG_0, 0, %CONVERTTOPYTHON[qint64](pid));
-PyTuple_SET_ITEM(%PYARG_0, 1, %CONVERTTOPYTHON[QString](hostname));
-PyTuple_SET_ITEM(%PYARG_0, 2, %CONVERTTOPYTHON[QString](appname));
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[qint64](pid));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[QString](hostname));
+PyTuple_SetItem(%PYARG_0, 2, %CONVERTTOPYTHON[QString](appname));
 // @snippet qlockfile-getlockinfo
 
 // @snippet darwin_permission_plugin
@@ -2171,3 +2175,21 @@ QByteArray result = '<' + QByteArray(Py_TYPE(%PYSELF)->tp_name)
                     + %CPPSELF.absoluteFilePath().toUtf8() + "\")>";
 %PYARG_0 = Shiboken::String::fromCString(result.constData());
 // @snippet qdirlisting-direntry-repr
+
+// @snippet return-native-eventfilter-conversion
+%RETURN_TYPE %out = false;
+if (PySequence_Check(%PYARG_0) != 0 && PySequence_Size(%PYARG_0) == 2) {
+    Shiboken::AutoDecRef pyItem(PySequence_GetItem(%PYARG_0, 0));
+    %out = %CONVERTTOCPP[bool](pyItem);
+    if (result) {
+        Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
+        *result = %CONVERTTOCPP[qintptr](pyResultItem);
+    }
+}
+// @snippet return-native-eventfilter-conversion
+
+// @snippet return-native-eventfilter
+%PYARG_0 = PyTuple_New(2);
+PyTuple_SetItem(%PYARG_0, 0, %CONVERTTOPYTHON[%RETURN_TYPE](%0));
+PyTuple_SetItem(%PYARG_0, 1, %CONVERTTOPYTHON[qintptr](*result_out));
+// @snippet return-native-eventfilter
